@@ -3,6 +3,7 @@ import ethereum
 from eth_utils import is_hex_address
 from django import forms
 from django.utils.translation import ugettext_lazy as _
+from ethereum.utils import ecrecover_to_pub
 
 
 def sig_to_vrs(sig):
@@ -21,7 +22,7 @@ def hash_personal_message(msg):
 def recover_to_addr(msg, sig):
     msghash = hash_personal_message(msg)
     vrs = sig_to_vrs(sig)
-    return '0x' + sha3.keccak_256(ethereum.utils.ecrecover_to_pub(msghash, *vrs)).hexdigest()[24:]
+    return '0x' + sha3.keccak_256(ecrecover_to_pub(msghash, *vrs)).hexdigest()[24:]
 
 
 def validate_eth_address(value):
